==> l_comp_lib_2017.0.098_comp.for_redist.tgz: l_comp_lib_2017.0.098_comp.for_redist/bin/compilervars.sh <==
#!/bin/sh
# Copyright  (C) 1985-2016 Intel Corporation. All rights reserved.
#
# The information and source code contained herein is the exclusive property
# of Intel Corporation and may not be disclosed, examined, or reproduced in
# whole or in part without explicit written authorization from the Company.
#
# Invoke this script with the 'source' command. For example:
#
#    source <my_install_location>/bin/compilervars.sh [ ia32 | intel64 ]

INSTALL_DIR="<INSTALLDIR>"
PROD_DIR="<PRODDIR>"

if [ "$1" != "ia32" -a "$1" != "intel64" ]; then
  echo "ERROR: Unknown switch "$1". Accepted values: ia32, intel64"
  case $0 in
    *compilervars*)
        exit 1;
        ;;
  esac
  return 1;
fi

ARCH=""$1"_lin"
ARCH_MIC="intel64_lin_mic"

if [ -z "${PATH}" ]
then
    PATH="${INSTALL_DIR}/bin"; export PATH
else
    PATH="${INSTALL_DIR}/bin:${PATH}"; export PATH
fi

if [ -z "${LD_LIBRARY_PATH}" ]
then
    LD_LIBRARY_PATH="${PROD_DIR}/compiler/lib/${ARCH}"; export LD_LIBRARY_PATH
else
    LD_LIBRARY_PATH="${PROD_DIR}/compiler/lib/${ARCH}:${LD_LIBRARY_PATH}"; export LD_LIBRARY_PATH
fi

if [ -z "${LIBRARY_PATH}" ]
   then
       LIBRARY_PATH="${PROD_DIR}/compiler/lib/${ARCH}"; export LIBRARY_PATH
   else
       LIBRARY_PATH="${PROD_DIR}/compiler/lib/${ARCH}:${LIBRARY_PATH}"; export LIBRARY_PATH
fi

if [ -z "${MIC_LD_LIBRARY_PATH}" ]
   then
      MIC_LD_LIBRARY_PATH="${PROD_DIR}/compiler/lib/${ARCH_MIC}"; export MIC_LD_LIBRARY_PATH
   else
      MIC_LD_LIBRARY_PATH="${PROD_DIR}/compiler/lib/${ARCH_MIC}:${MIC_LD_LIBRARY_PATH}"; export MIC_LD_LIBRARY_PATH
fi

if [ -z "${NLSPATH}" ] 
   then
      NLSPATH="${PROD_DIR}/compiler/lib/${ARCH}/locale/%l_%t/%N"; export NLSPATH
   else
      NLSPATH="${PROD_DIR}/compiler/lib/${ARCH}/locale/%l_%t/%N:${NLSPATH}"; export NLSPATH
fi

if [ "$1" = "ia32" ]
then
    if [ -d "${PROD_DIR}/mpirt/bin/${ARCH}" ]; then
        PATH="${PROD_DIR}/mpirt/bin/${ARCH}:${PATH}"; export PATH
    fi
    if [ -d "${PROD_DIR}/mpirt/lib/${ARCH}" ]; then
        LD_LIBRARY_PATH="${PROD_DIR}/mpirt/lib/${ARCH}:${LD_LIBRARY_PATH}"; export LD_LIBRARY_PATH
    fi
else
    if [ -e "${PROD_DIR}/mpi/intel64/bin/mpivars.sh" ]; then
        . "${PROD_DIR}/mpi/intel64/bin/mpivars.sh"
    fi
    
    if [ -d "${PROD_DIR}/mpi/mic/lib" ]; then
        MIC_LD_LIBRARY_PATH="${PROD_DIR}/mpi/mic/lib:${MIC_LD_LIBRARY_PATH}"; export MIC_LD_LIBRARY_PATH
    fi    
fi

==> l_comp_lib_2017.5.239_comp.for_redist.tgz: l_comp_lib_2017.5.239_comp.for_redist/bin/compilervars.sh <==
#!/bin/sh
# Copyright  (C) 1985-2017 Intel Corporation. All rights reserved.
#
# The information and source code contained herein is the exclusive property
# of Intel Corporation and may not be disclosed, examined, or reproduced in
# whole or in part without explicit written authorization from the Company.
#
# Invoke this script with the 'source' command. For example:
#
#    source <my_install_location>/bin/compilervars.sh [ ia32 | intel64 ]

INSTALL_DIR="<INSTALLDIR>"
PROD_DIR="<PRODDIR>"

if [ "$1" = "ia32" -o "$1" = "intel64" ]; then
  ARCH=""$1"_lin"
elif [ -n "$COMPILERVARS_ARCHITECTURE" ]; then
  if [ "$COMPILERVARS_ARCHITECTURE" = "ia32" -o "$COMPILERVARS_ARCHITECTURE" = "intel64" ]; then
    ARCH=$COMPILERVARS_ARCHITECTURE
  else
    echo "ERROR: Unknown switch '$COMPILERVARS_ARCHITECTURE'. Accepted values: ia32, intel64"
    exit 1
  fi
else
  echo "ERROR: Unknown switch '$1'. Accepted values: ia32, intel64"
  exit 1
fi

ARCH_MIC="intel64_lin_mic"

if [ -z "${PATH}" ]
then
    PATH="${INSTALL_DIR}/bin"; export PATH
else
    PATH="${INSTALL_DIR}/bin:${PATH}"; export PATH
fi

if [ -z "${LD_LIBRARY_PATH}" ]
then
    LD_LIBRARY_PATH="${PROD_DIR}/compiler/lib/${ARCH}"; export LD_LIBRARY_PATH
else
    LD_LIBRARY_PATH="${PROD_DIR}/compiler/lib/${ARCH}:${LD_LIBRARY_PATH}"; export LD_LIBRARY_PATH
fi

if [ -z "${LIBRARY_PATH}" ]
   then
       LIBRARY_PATH="${PROD_DIR}/compiler/lib/${ARCH}"; export LIBRARY_PATH
   else
       LIBRARY_PATH="${PROD_DIR}/compiler/lib/${ARCH}:${LIBRARY_PATH}"; export LIBRARY_PATH
fi

if [ -z "${MIC_LD_LIBRARY_PATH}" ]
   then
      MIC_LD_LIBRARY_PATH="${PROD_DIR}/compiler/lib/${ARCH_MIC}"; export MIC_LD_LIBRARY_PATH
   else
      MIC_LD_LIBRARY_PATH="${PROD_DIR}/compiler/lib/${ARCH_MIC}:${MIC_LD_LIBRARY_PATH}"; export MIC_LD_LIBRARY_PATH
fi

if [ -z "${NLSPATH}" ] 
   then
      NLSPATH="${PROD_DIR}/compiler/lib/${ARCH}/locale/%l_%t/%N"; export NLSPATH
   else
      NLSPATH="${PROD_DIR}/compiler/lib/${ARCH}/locale/%l_%t/%N:${NLSPATH}"; export NLSPATH
fi

if [ "$1" = "ia32" ]
then
    if [ -d "${PROD_DIR}/mpirt/bin/${ARCH}" ]; then
        PATH="${PROD_DIR}/mpirt/bin/${ARCH}:${PATH}"; export PATH
    fi
    if [ -d "${PROD_DIR}/mpirt/lib/${ARCH}" ]; then
        LD_LIBRARY_PATH="${PROD_DIR}/mpirt/lib/${ARCH}:${LD_LIBRARY_PATH}"; export LD_LIBRARY_PATH
    fi
else
    if [ -e "${PROD_DIR}/mpi/intel64/bin/mpivars.sh" ]; then
        . "${PROD_DIR}/mpi/intel64/bin/mpivars.sh"
    fi
    
    if [ -d "${PROD_DIR}/mpi/mic/lib" ]; then
        MIC_LD_LIBRARY_PATH="${PROD_DIR}/mpi/mic/lib:${MIC_LD_LIBRARY_PATH}"; export MIC_LD_LIBRARY_PATH
    fi    
fi
